@@ -1,5 +1,5 @@
 .plt.bad <-
-function (x.miss, y.miss, values, breaks, bin.start, n.row, n.col,
+function (x.miss, y.miss, topic, breaks, bin.start, n.row, n.col,
           MD.cut, out.cut, fit.se, ...) {
 
   # check for inconsistent parameters
@@ -19,7 +19,7 @@ function (x.miss, y.miss, values, breaks, bin.start, n.row, n.col,
       "fit.se now specified as the confidence level, between 0 and 1\n\n")
   }
   
-  if (values %in% c("mean", "sd", "min", "max") && y.miss) {
+  if (topic %in% c("mean", "sd", "min", "max") && y.miss) {
       cat("\n"); stop(call.=FALSE, "\n","------\n",
       "Must specify a numeric y-variable from which to compute the\n ",
       " ", values, " for each level of ", deparse(substitute(x)), "\n\n")
